# Guides Overview

SuperOptiX lets you define agents once in SuperSpec YAML and compile them into multiple frameworks.

## Highlighted Capabilities

- 🧪 [RLM (Experimental)](rlm-experimental.md)
- 🗂️ [StackOne Connectors](stackone-integration.md)
- 🧬 [GEPA Optimization](gepa-optimization.md)

## Start Here

- [SuperSpec Overview](superspec.md)
- [Multi-Framework Guide](multi-framework.md)
- [Golden Workflow](golden-workflow.md)
- [CLI Complete Guide](cli-complete-guide.md)

## Framework Guides

- [DSPy](multi-framework.md#supported-frameworks)
- [Framework Feature Matrix](framework-feature-matrix.md)
- [OpenAI Agents SDK](openai-sdk-integration.md)
- [Claude Agent SDK](claude-sdk-integration.md)
- [Pydantic AI](pydantic-ai-integration.md)
- [CrewAI](crewai-integration.md)
- [Google ADK](google-adk-integration.md)
- [DeepAgents](deepagents-integration.md)
- [Microsoft Agent Framework (Legacy Support)](microsoft-framework-integration.md)

## Connectors

- [StackOne Integration](stackone-integration.md)
- [StackOne + Claude SDK](stackone-claude-sdk.md)

## Optimization and Evaluation

- [GEPA Optimization](gepa-optimization.md)
- [RLM (Experimental)](rlm-experimental.md)
- [Optimization Guide](optimization.md)
- [Evaluation & Testing](evaluation-testing.md)

## Observability

- [Observability Guide](observability.md)
- [MLFlow](mlflow-guide.md)
- [LangFuse](langfuse-integration.md)
- [LogFire](logfire-integration.md)

## Troubleshooting

- [Troubleshooting by Symptom](troubleshooting-by-symptom.md)
